from utils.db.config import ConfigDB
from utils.db.keys import KeysDB
# Important: fix the import path to match your real folder name: engines NOT Search
from engines.git.github.sniffer import run_engine

def main_menu():
    while True:
        print("\n=== Main Menu ===")
        print("1) Search")
        print("2) Settings")
        print("0) Exit")

        choice = input("Choose an option: ")
        if choice == '1':
            search_menu()
        elif choice == '2':
            settings_menu()
        elif choice == '0':
            print("Exiting...")
            break
        else:
            print("Invalid choice.")

def search_menu():
    while True:
        print("\n=== Search ===")
        print("1) git")
        print("0) Back")

        choice = input("Choose an option: ")
        if choice == '1':
            git_menu_search()
        elif choice == '0':
            break
        else:
            print("Invalid choice.")

def git_menu_search():
    while True:
        print("\n=== git ===")
        print("1) GitHub")
        print("0) Back")

        choice = input("Choose an option: ")
        if choice == '1':
            github_sniffer_menu()
        elif choice == '0':
            break
        else:
            print("Invalid choice.")

def github_sniffer_menu():
    while True:
        print("\n=== GitHub ===")
        print("1) Run sniffer")
        print("0) Back")

        choice = input("Choose an option: ")
        if choice == '1':
            run_engine()  # Calls the sniffer in engines/git/github/sniffer.py
        elif choice == '0':
            break
        else:
            print("Invalid choice.")

def settings_menu():
    while True:
        print("\n=== Settings ===")
        print("1) Git")
        print("0) Back")

        choice = input("Choose an option: ")
        if choice == '1':
            git_menu_settings()
        elif choice == '0':
            break
        else:
            print("Invalid choice.")

def git_menu_settings():
    while True:
        print("\n=== Git ===")
        print("1) GitHub")
        print("0) Back")

        choice = input("Choose an option: ")
        if choice == '1':
            github_menu_settings()
        elif choice == '0':
            break
        else:
            print("Invalid choice.")

def github_menu_settings():
    while True:
        print("\n=== GitHub Settings ===")
        print("1) Add GitHub Key")
        print("2) List GitHub Keys")
        print("3) Edit GitHub Keys")
        print("0) Back")

        choice = input("Choose an option: ")
        if choice == '1':
            new_key = input("Enter a new GitHub key: ")
            if new_key.strip():
                with ConfigDB() as db:
                    db.add_github_key(new_key.strip())
                print("Key added.")
            else:
                print("No key entered.")
        elif choice == '2':
            with ConfigDB() as db:
                keys = db.list_github_keys()
            if not keys:
                print("No GitHub keys found.")
            else:
                for i, key_val in enumerate(keys, start=1):
                    print(f"{i}) {key_val}")
        elif choice == '3':
            with ConfigDB() as db:
                keys = db.list_github_keys_with_ids()
            if not keys:
                print("No GitHub keys found.")
            else:
                for i, (row_id, key_val) in enumerate(keys, start=1):
                    print(f"{i}) {key_val}")
                picked = input("Enter item number to edit (0 to cancel): ")
                if picked.isdigit():
                    picked_num = int(picked)
                    if picked_num == 0:
                        pass
                    elif 1 <= picked_num <= len(keys):
                        row_id, old_key = keys[picked_num-1]
                        new_val = input(f"Current key: {old_key}\n"
                                        "Enter new key (leave empty to delete): ")
                        if not new_val.strip():
                            with ConfigDB() as db:
                                db.delete_github_key_by_id(row_id)
                            print("Key deleted.")
                        else:
                            with ConfigDB() as db:
                                db.update_github_key_by_id(row_id, new_val.strip())
                            print("Key updated.")
                    else:
                        print("Invalid item number.")
                else:
                    print("Enter a valid number.")
        elif choice == '0':
            break
        else:
            print("Invalid choice.")

if __name__ == "__main__":
    # Ensure both DBs have their tables created.
    with ConfigDB():
        pass
    with KeysDB():
        pass
    main_menu()
