import sqlite3
import os
from datetime import datetime

DB_PATH = os.path.join(
    os.path.dirname(__file__),
    '../../cache/db/keys.db'
)

class KeysDB:
    def __init__(self, db_path=DB_PATH):
        self.conn = sqlite3.connect(db_path)
        self.create_tables()

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_value, traceback):
        self.close()

    def create_tables(self):
        """
        Create table for storing discovered keys.
        """
        cursor = self.conn.cursor()
        cursor.execute('''
            CREATE TABLE IF NOT EXISTS found (
                id INTEGER PRIMARY KEY AUTOINCREMENT,
                engine_name TEXT NOT NULL,
                key_value TEXT NOT NULL,
                date_added TEXT DEFAULT CURRENT_TIMESTAMP
            )
        ''')
        self.conn.commit()

    def insert_found_key(self, engine_name, key_value):
        """
        Insert a discovered key into the 'found' table.
        """
        cursor = self.conn.cursor()
        cursor.execute('''
            INSERT INTO found (engine_name, key_value, date_added)
            VALUES (?, ?, ?)
        ''', (engine_name, key_value, datetime.utcnow().isoformat()))
        self.conn.commit()

    def close(self):
        self.conn.close()
