import os
import glob
import importlib.util
import re
from utils.db.keys import KeysDB

def list_dorks():
    """
    Dynamically discover all *.py dork modules under /dorks/git/github.
    """
    base_path = os.path.join(
        os.path.dirname(__file__),
        '../../../dorks/git/github'  # 3x ../ from engines/git/github to top-level
    )
    py_files = glob.glob(os.path.join(base_path, '*.py'))
    modules = []
    for py_file in py_files:
        filename = os.path.basename(py_file)
        if filename == '__init__.py':
            continue

        mod_name = filename[:-3]  # remove .py
        spec = importlib.util.spec_from_file_location(mod_name, py_file)
        mod = importlib.util.module_from_spec(spec)
        spec.loader.exec_module(mod)
        modules.append((mod_name, mod))
    return modules

def run_search_with_dork(dork_module):
    """
    Demo logic: pretend to parse text for the dork’s REGEX_LIST
    and insert matches into keys.db.
    """
    sample_lines = [
        "Look here: pplx-0123456789abcdef0123456789abcdef01234567",
        "Some random text with no keys."
    ]
    found = []
    for line in sample_lines:
        for regex in dork_module.REGEX_LIST:
            matches = regex.findall(line)
            found.extend(matches)

    if found:
        print(f"[+] {getattr(dork_module, 'NAME', 'UnknownDork')} found matches:")
        for match in found:
            print(f"    {match}")
        with KeysDB() as db:
            for match in found:
                db.insert_found_key(getattr(dork_module, 'NAME', 'UnknownDork'), match)
    else:
        print(f"[-] {getattr(dork_module, 'NAME', 'UnknownDork')} found no matches.")

def run_engine():
    """
    Lists the discovered Dork modules, prompts user to choose or run all.
    """
    dorks = list_dorks()
    if not dorks:
        print("No dorks found in /dorks/git/github/")
        return

    while True:
        print("\n=== GitHub Sniffer ===")
        print("0) Back")
        for i, (_, mod_ref) in enumerate(dorks, start=1):
            dork_name = getattr(mod_ref, 'NAME', f'Dork{i}')
            print(f"{i}) {dork_name}")
        print(f"{len(dorks)+1}) Run ALL dorks")

        choice = input("Choose an option: ")
        if not choice.isdigit():
            print("Please enter a number.")
            continue

        choice = int(choice)
        if choice == 0:
            break
        elif 1 <= choice <= len(dorks):
            _, selected_mod = dorks[choice - 1]
            run_search_with_dork(selected_mod)
        elif choice == len(dorks) + 1:
            for _, mod_ref in dorks:
                run_search_with_dork(mod_ref)
        else:
            print("Invalid choice.")
